@@ -1,21 +1,8 @@
 /*
-   Copyright (C) 2003-2005 George Staikos <staikos@kde.org>
-   Copyright (C) 2005 Isaac Clerencia <isaac@warp.es>
+    SPDX-FileCopyrightText: 2003-2005 George Staikos <staikos@kde.org>
+    SPDX-FileCopyrightText: 2005 Isaac Clerencia <isaac@warp.es>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef KWALLETEDITOR_H
@@ -42,7 +29,7 @@ class KWalletEditor : public QWidget, public Ui::WalletWidget
 
 public:
     explicit KWalletEditor(QWidget *parent, const QString &name = QString());
-    virtual ~KWalletEditor();
+    ~KWalletEditor() override;
 
     void setWallet(KWallet::Wallet *wallet, bool isPath = false);
     bool isOpen() const;
